@@ -1,8 +1,7 @@
-import *
+from configCmtPack import *
 import logging
-logging.basicConfig(level=logging.info,
+logging.basicConfig(level=logging.INFO,
                     format='[%(levelname)s] %(message)s')
-print("Info")
 #log = logging.getLogger(__name__)
 # CRITICAL: 50
 # ERROR: 40
